@@ -3,7 +3,7 @@ function(x, ...)
 {
     attr(x,"class") <- "data.frame"
     nn <- c("", "Number of subjects at risk", "Number of events", "Total time of follow-up",
-          "Time of follow-up (median)", "Mean episodes per subject", "Density of incidence")
+          "Time of follow-up (median)", "Density of incidence")
     for (i in 2:length(x))
     {
       cat("\n")
